summaryrefslogtreecommitdiffhomepage
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/net/jao-notmuch.el10
1 files changed, 8 insertions, 2 deletions
diff --git a/lib/net/jao-notmuch.el b/lib/net/jao-notmuch.el
index b67c788..626eee8 100644
--- a/lib/net/jao-notmuch.el
+++ b/lib/net/jao-notmuch.el
@@ -196,8 +196,14 @@
(setq mm-text-html-renderer #'jao-w3m-gnus-html-renderer)
-
-;; Keeping track of unread messages in current tree view
+;;;; Using arbitrary functions as "fields" in notmuch-tree-result-format
+
+(defun jao-notmuch--format-field (fun field fmt msg)
+ (if (symbolp field) (funcall field msg) (funcall fun field fmt msg)))
+
+(advice-add 'notmuch-tree-format-field :around #'jao-notmuch--format-field)
+
+;;;; Keeping track of unread messages in current tree view
(defvar-local jao-notmuch--query-name nil)